==> ui-canvas-0.1.0-sources.jar: commonMain/com/cerve/development/ui/canvas/operators/Background.kt <==
package com.cerve.development.ui.canvas.operators

import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.drawWithCache
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.drawscope.translate
import androidx.compose.ui.graphics.graphicsLayer
import com.cerve.development.ui.canvas.model.CerveCanvasGridProperties
import com.cerve.development.ui.canvas.model.CerveOffset

fun Modifier.drawGrid(
    color: Color,
    properties: CerveCanvasGridProperties,
    showGridLine: Boolean
) : Modifier = if (showGridLine) {
    drawWithCache {
        onDrawBehind {
            translate(
                left = properties.translationAmount.x,
                top = properties.translationAmount.y
            ) {
                (0..properties.gridLineCount).forEach { x ->

                    val gridLinePair = properties.gridLine(x)

                    drawLine(
                        start = gridLinePair.xLine.start.offset,
                        end = gridLinePair.xLine.end.offset,
                        color = color
                    )
                    drawLine(
                        start = gridLinePair.yLine.start.offset,
                        end = gridLinePair.yLine.end.offset,
                        color = color
                    )

                }
            }
        }

    }
} else this

fun Modifier.changeOrientation(
    scale: () -> Float,
    rotation: () -> Float,
    offset: () -> CerveOffset
) : Modifier = graphicsLayer {
    scaleX = scale()
    scaleY = scale()
    rotationZ = rotation()
    val offset = offset()
    translationX = offset.x.toFloat()
    translationY = offset.y.toFloat()
}

==> ui-canvas-0.1.7-sources.jar: commonMain/com/cerve/development/ui/canvas/operators/Background.kt <==
package com.cerve.development.ui.canvas.operators

import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.drawWithCache
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.drawscope.translate
import androidx.compose.ui.graphics.graphicsLayer
import com.cerve.development.ui.canvas.model.CerveCanvasGridProperties
import com.cerve.development.ui.canvas.model.CerveCanvasTransformations

fun Modifier.drawGrid(
    color: Color,
    properties: CerveCanvasGridProperties,
    shouldShowGridLine: Boolean
) : Modifier = if (shouldShowGridLine) {
    drawWithCache {
        onDrawBehind {
            translate(
                left = properties.gridCenter.x,
                top = properties.gridCenter.y
            ) {
                (0..properties.gridLineCount).forEach { x ->

                    val gridLinePair = properties.gridLine(x)

                    drawLine(
                        start = gridLinePair.xLine.start.offset,
                        end = gridLinePair.xLine.end.offset,
                        color = color
                    )
                    drawLine(
                        start = gridLinePair.yLine.start.offset,
                        end = gridLinePair.yLine.end.offset,
                        color = color
                    )

                }
            }
        }

    }
} else this

fun Modifier.graphicLayerTransformation(
    transformations: () -> CerveCanvasTransformations
) : Modifier = graphicsLayer {
    scaleX = transformations().scale
    scaleY = transformations().scale
    rotationZ = transformations().rotation
    translationX = transformations().offset.x.toFloat()
    translationY = transformations().offset.y.toFloat()
}
